@@ -1,4 +1,4 @@
-/* Copyright (C) 1993-2013 Free Software Foundation, Inc.
+/* Copyright (C) 1993-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -31,9 +31,7 @@
 #ifndef __OFF_T_MATCHES_OFF64_T
 
 int
-_IO_new_fgetpos64 (fp, posp)
-     _IO_FILE *fp;
-     _IO_fpos64_t *posp;
+_IO_new_fgetpos64 (_IO_FILE *fp, _IO_fpos64_t *posp)
 {
   _IO_off64_t pos;
   int result = 0;
