@@ -1,4 +1,4 @@
-/* Copyright (C) 1993-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1993-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -28,10 +28,7 @@
 #include <stdio.h>
 
 char *
-__fgets_unlocked (buf, n, fp)
-     char *buf;
-     int n;
-     _IO_FILE *fp;
+__fgets_unlocked (char *buf, int n, _IO_FILE *fp)
 {
   _IO_size_t count;
   char *result;
