@@ -1,4 +1,4 @@
-/* Copyright (C) 1994-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1994-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -41,9 +41,10 @@ extern mach_port_t __mach_thread_self (void);
 extern mach_port_t (mach_task_self) (void);
 extern mach_port_t (__mach_task_self) (void);
 
-/* Return the host information port for the host of the calling task.  */
-extern mach_port_t mach_host_self (void);
-extern mach_port_t __mach_host_self (void);
+/* Return the host information port for the host of the calling task.
+   The parens are needed to protect against the macro in <mach_init.h>.  */
+extern mach_port_t (mach_host_self) (void);
+extern mach_port_t (__mach_host_self) (void);
 
 /* Attempt to context switch the current thread off the processor.  Returns
    true if there are other threads that can be run and false if not.  */
@@ -57,7 +58,7 @@ extern boolean_t __swtch (void);
 extern boolean_t swtch_pri (int priority);
 extern boolean_t __swtch_pri (int priority);
 
-/* Attempt to context switch the current thread of the processor.  Try
+/* Attempt to context switch the current thread off the processor.  Try
    to run NEW_THREAD next, ignoring normal scheduling policies.  The
    OPTION value comes from <mach/thread_switch.h>.  If OPTION is
    SWITCH_OPTION_WAIT, then block the current thread for TIME
@@ -74,5 +75,10 @@ kern_return_t __thread_switch (mach_port_t new_thread,
 kern_return_t evc_wait (unsigned int event);
 kern_return_t __evc_wait (unsigned int event);
 
+/* Display a null-terminated character string on the Mach console. This
+   system call is meant as a debugging tool useful to circumvent messaging
+   altogether.  */
+
+extern void mach_print(const char *s);
 
 #endif	/* mach/mach_traps.h */
