@@ -1,4 +1,4 @@
-/* Copyright (C) 2002-2014 Free Software Foundation, Inc.
+/* Copyright (C) 2002-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@redhat.com>, 2002.
 
@@ -22,8 +22,7 @@
 
 
 int
-pthread_key_delete (key)
-     pthread_key_t key;
+pthread_key_delete (pthread_key_t key)
 {
   int result = EINVAL;
 
