@@ -1,6 +1,6 @@
-/* Check recvmmsg cancellation.
+/* Check sendmmsg cancellation.
 
-   Copyright (C) 2016 Free Software Foundation, Inc.
+   Copyright (C) 2016-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -32,8 +32,13 @@
 #include "tst-cancel4-common.h"
 
 static void *
-tf_recvmmsg (void *arg)
+tf_sendmmsg (void *arg)
 {
+  if (arg == NULL)
+    // XXX If somebody can provide a portable test case in which sendmmsg()
+    // blocks we can enable this test to run in both rounds.
+    abort ();
+
   struct sockaddr_un sun;
 
   tempfd = socket (AF_UNIX, SOCK_DGRAM, 0);
@@ -51,7 +56,7 @@ tf_recvmmsg (void *arg)
 	  printf ("%s: too many unsuccessful bind calls\n", __FUNCTION__);
 	}
 
-      strcpy (sun.sun_path, "/tmp/tst-cancel4-socket-5-XXXXXX");
+      strcpy (sun.sun_path, "/tmp/tst-cancel4-socket-7-XXXXXX");
       if (mktemp (sun.sun_path) == NULL)
 	{
 	  printf ("%s: cannot generate temp file name\n", __FUNCTION__);
@@ -63,7 +68,6 @@ tf_recvmmsg (void *arg)
   while (bind (tempfd, (struct sockaddr *) &sun,
 	       offsetof (struct sockaddr_un, sun_path)
 	       + strlen (sun.sun_path) + 1) != 0);
-
   tempfname = strdup (sun.sun_path);
 
   tempfd2 = socket (AF_UNIX, SOCK_DGRAM, 0);
@@ -80,45 +84,43 @@ tf_recvmmsg (void *arg)
       exit (1);
     }
 
-  if (arg != NULL)
+  r = pthread_barrier_wait (&b2);
+  if (r != 0 && r != PTHREAD_BARRIER_SERIAL_THREAD)
     {
-      r = pthread_barrier_wait (&b2);
-      if (r != 0 && r != PTHREAD_BARRIER_SERIAL_THREAD)
-	{
-	  printf ("%s: 2nd barrier_wait failed\n", __FUNCTION__);
-	  exit (1);
-	}
+      printf ("%s: 2nd barrier_wait failed\n", __FUNCTION__);
+      exit (1);
     }
 
   pthread_cleanup_push (cl, NULL);
 
-  char mem[70];
+  char mem[1];
   struct iovec iov[1];
   iov[0].iov_base = mem;
-  iov[0].iov_len = arg == NULL ? sizeof (mem) : 0;
+  iov[0].iov_len = 1;
 
   struct mmsghdr mm;
   mm.msg_hdr.msg_name = &sun;
-  mm.msg_hdr.msg_namelen = sizeof (sun);
+  mm.msg_hdr.msg_namelen = (offsetof (struct sockaddr_un, sun_path)
+			   + strlen (sun.sun_path) + 1);
   mm.msg_hdr.msg_iov = iov;
   mm.msg_hdr.msg_iovlen = 1;
   mm.msg_hdr.msg_control = NULL;
   mm.msg_hdr.msg_controllen = 0;
 
-  ssize_t ret = recvmmsg (tempfd2, &mm, 1, 0, NULL);
+  ssize_t ret = sendmmsg (tempfd2, &mm, 1, 0);
   if (ret == -1 && errno == ENOSYS)
     exit (77);
 
   pthread_cleanup_pop (0);
 
-  printf ("%s: recvmmsg returned\n", __FUNCTION__);
+  printf ("%s: sendmmsg returned\n", __FUNCTION__);
 
   exit (1);
 }
 
 struct cancel_tests tests[] =
 {
-  ADD_TEST (recvmmsg, 2, 1),
+  ADD_TEST (sendmmsg, 2, 1),
 };
 #define ntest_tf (sizeof (tests) / sizeof (tests[0]))
 
