@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -22,8 +22,7 @@
 
 /* Test whether SET is empty.  */
 int
-sigisemptyset (set)
-     const sigset_t *set;
+sigisemptyset (const sigset_t *set)
 {
   if (set == NULL)
     {
