@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2014 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -21,13 +21,8 @@
 /* Send N bytes of BUF on socket FD to peer at address ADDR (which is
    ADDR_LEN bytes long).  Returns the number sent, or -1 for errors.  */
 ssize_t
-__sendto (fd, buf, n, flags, addr, addr_len)
-     int fd;
-     const __ptr_t buf;
-     size_t n;
-     int flags;
-     __CONST_SOCKADDR_ARG addr;
-     socklen_t addr_len;
+__sendto (int fd, const __ptr_t buf, size_t n, int flags,
+	  __CONST_SOCKADDR_ARG addr, socklen_t addr_len)
 {
   __set_errno (ENOSYS);
   return -1;
