@@ -1,5 +1,5 @@
 /* Tests for gets.
-   Copyright (C) 2001, 2011, 2012 Free Software Foundation, Inc.
+   Copyright (C) 2001-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@redhat.com>, 2001.
 
@@ -21,8 +21,8 @@
 #include <string.h>
 
 
-int
-main (void)
+static int
+do_test (void)
 {
   char buf[100];
   int result = 0;
@@ -61,3 +61,6 @@ main (void)
 
   return result;
 }
+
+#define TEST_FUNCTION do_test ()
+#include "../test-skeleton.c"
