@@ -1,5 +1,5 @@
 /* `long long int' absolute value.
-   Copyright (C) 1991, 1996, 1997 Free Software Foundation, Inc.
+   Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -13,9 +13,8 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   License along with the GNU C Library; if not, see
+   <http://www.gnu.org/licenses/>.  */
 
 #include <stdlib.h>
 
@@ -24,8 +23,7 @@
 
 /* Return the absolute value of I.  */
 long long int
-llabs (i)
-     long long int i;
+llabs (long long int i)
 {
   return i < 0 ? -i : i;
 }
