@@ -1,4 +1,4 @@
-/* Copyright (C) 1998 Free Software Foundation, Inc.
+/* Copyright (C) 1998-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -19,12 +19,8 @@
 #include <stropts.h>
 
 int
-getpmsg (fildes, ctlptr, dataptr, bandp, flagsp)
-     int fildes;
-     struct strbuf *ctlptr;
-     struct strbuf *dataptr;
-     int *bandp;
-     int *flagsp;
+getpmsg (int fildes, struct strbuf *ctlptr, struct strbuf *dataptr, int *bandp,
+	 int *flagsp)
 {
   __set_errno (ENOSYS);
   return -1;
@@ -32,4 +28,3 @@ getpmsg (fildes, ctlptr, dataptr, bandp, flagsp)
 
 
 stub_warning (getpmsg)
-#include <stub-tag.h>
