@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Torbjorn Granlund (tege@sics.se).
 
@@ -24,8 +24,7 @@
 
 /* Find the first bit set in I.  */
 int
-__ffs (i)
-     int i;
+__ffs (int i)
 {
   static const unsigned char table[] =
     {
