@@ -57,101 +57,101 @@
 #include <math.h>
 #include <math_private.h>
 
-static const long double
-  one = 1.0L,
-  pio2_hi = 1.5707963267948966192313216916397514420986L,
-  pio2_lo = 4.3359050650618905123985220130216759843812E-35L,
+static const _Float128
+  one = 1,
+  pio2_hi = L(1.5707963267948966192313216916397514420986),
+  pio2_lo = L(4.3359050650618905123985220130216759843812E-35),
 
   /* acos(0.5625 + x) = acos(0.5625) + x rS(x) / sS(x)
      -0.0625 <= x <= 0.0625
      peak relative error 3.3e-35  */
 
-  rS0 =  5.619049346208901520945464704848780243887E0L,
-  rS1 = -4.460504162777731472539175700169871920352E1L,
-  rS2 =  1.317669505315409261479577040530751477488E2L,
-  rS3 = -1.626532582423661989632442410808596009227E2L,
-  rS4 =  3.144806644195158614904369445440583873264E1L,
-  rS5 =  9.806674443470740708765165604769099559553E1L,
-  rS6 = -5.708468492052010816555762842394927806920E1L,
-  rS7 = -1.396540499232262112248553357962639431922E1L,
-  rS8 =  1.126243289311910363001762058295832610344E1L,
-  rS9 =  4.956179821329901954211277873774472383512E-1L,
-  rS10 = -3.313227657082367169241333738391762525780E-1L,
+  rS0 =  L(5.619049346208901520945464704848780243887E0),
+  rS1 = L(-4.460504162777731472539175700169871920352E1),
+  rS2 =  L(1.317669505315409261479577040530751477488E2),
+  rS3 = L(-1.626532582423661989632442410808596009227E2),
+  rS4 =  L(3.144806644195158614904369445440583873264E1),
+  rS5 =  L(9.806674443470740708765165604769099559553E1),
+  rS6 = L(-5.708468492052010816555762842394927806920E1),
+  rS7 = L(-1.396540499232262112248553357962639431922E1),
+  rS8 =  L(1.126243289311910363001762058295832610344E1),
+  rS9 =  L(4.956179821329901954211277873774472383512E-1),
+  rS10 = L(-3.313227657082367169241333738391762525780E-1),
 
-  sS0 = -4.645814742084009935700221277307007679325E0L,
-  sS1 =  3.879074822457694323970438316317961918430E1L,
-  sS2 = -1.221986588013474694623973554726201001066E2L,
-  sS3 =  1.658821150347718105012079876756201905822E2L,
-  sS4 = -4.804379630977558197953176474426239748977E1L,
-  sS5 = -1.004296417397316948114344573811562952793E2L,
-  sS6 =  7.530281592861320234941101403870010111138E1L,
-  sS7 =  1.270735595411673647119592092304357226607E1L,
-  sS8 = -1.815144839646376500705105967064792930282E1L,
-  sS9 = -7.821597334910963922204235247786840828217E-2L,
+  sS0 = L(-4.645814742084009935700221277307007679325E0),
+  sS1 =  L(3.879074822457694323970438316317961918430E1),
+  sS2 = L(-1.221986588013474694623973554726201001066E2),
+  sS3 =  L(1.658821150347718105012079876756201905822E2),
+  sS4 = L(-4.804379630977558197953176474426239748977E1),
+  sS5 = L(-1.004296417397316948114344573811562952793E2),
+  sS6 =  L(7.530281592861320234941101403870010111138E1),
+  sS7 =  L(1.270735595411673647119592092304357226607E1),
+  sS8 = L(-1.815144839646376500705105967064792930282E1),
+  sS9 = L(-7.821597334910963922204235247786840828217E-2),
   /* 1.000000000000000000000000000000000000000E0 */
 
-  acosr5625 = 9.7338991014954640492751132535550279812151E-1L,
-  pimacosr5625 = 2.1682027434402468335351320579240000860757E0L,
+  acosr5625 = L(9.7338991014954640492751132535550279812151E-1),
+  pimacosr5625 = L(2.1682027434402468335351320579240000860757E0),
 
   /* acos(0.4375 + x) = acos(0.4375) + x rS(x) / sS(x)
      -0.0625 <= x <= 0.0625
      peak relative error 2.1e-35  */
 
-  P0 =  2.177690192235413635229046633751390484892E0L,
-  P1 = -2.848698225706605746657192566166142909573E1L,
-  P2 =  1.040076477655245590871244795403659880304E2L,
-  P3 = -1.400087608918906358323551402881238180553E2L,
-  P4 =  2.221047917671449176051896400503615543757E1L,
-  P5 =  9.643714856395587663736110523917499638702E1L,
-  P6 = -5.158406639829833829027457284942389079196E1L,
-  P7 = -1.578651828337585944715290382181219741813E1L,
-  P8 =  1.093632715903802870546857764647931045906E1L,
-  P9 =  5.448925479898460003048760932274085300103E-1L,
-  P10 = -3.315886001095605268470690485170092986337E-1L,
-  Q0 = -1.958219113487162405143608843774587557016E0L,
-  Q1 =  2.614577866876185080678907676023269360520E1L,
-  Q2 = -9.990858606464150981009763389881793660938E1L,
-  Q3 =  1.443958741356995763628660823395334281596E2L,
-  Q4 = -3.206441012484232867657763518369723873129E1L,
-  Q5 = -1.048560885341833443564920145642588991492E2L,
-  Q6 =  6.745883931909770880159915641984874746358E1L,
-  Q7 =  1.806809656342804436118449982647641392951E1L,
-  Q8 = -1.770150690652438294290020775359580915464E1L,
-  Q9 = -5.659156469628629327045433069052560211164E-1L,
+  P0 =  L(2.177690192235413635229046633751390484892E0),
+  P1 = L(-2.848698225706605746657192566166142909573E1),
+  P2 =  L(1.040076477655245590871244795403659880304E2),
+  P3 = L(-1.400087608918906358323551402881238180553E2),
+  P4 =  L(2.221047917671449176051896400503615543757E1),
+  P5 =  L(9.643714856395587663736110523917499638702E1),
+  P6 = L(-5.158406639829833829027457284942389079196E1),
+  P7 = L(-1.578651828337585944715290382181219741813E1),
+  P8 =  L(1.093632715903802870546857764647931045906E1),
+  P9 =  L(5.448925479898460003048760932274085300103E-1),
+  P10 = L(-3.315886001095605268470690485170092986337E-1),
+  Q0 = L(-1.958219113487162405143608843774587557016E0),
+  Q1 =  L(2.614577866876185080678907676023269360520E1),
+  Q2 = L(-9.990858606464150981009763389881793660938E1),
+  Q3 =  L(1.443958741356995763628660823395334281596E2),
+  Q4 = L(-3.206441012484232867657763518369723873129E1),
+  Q5 = L(-1.048560885341833443564920145642588991492E2),
+  Q6 =  L(6.745883931909770880159915641984874746358E1),
+  Q7 =  L(1.806809656342804436118449982647641392951E1),
+  Q8 = L(-1.770150690652438294290020775359580915464E1),
+  Q9 = L(-5.659156469628629327045433069052560211164E-1),
   /* 1.000000000000000000000000000000000000000E0 */
 
-  acosr4375 = 1.1179797320499710475919903296900511518755E0L,
-  pimacosr4375 = 2.0236129215398221908706530535894517323217E0L,
+  acosr4375 = L(1.1179797320499710475919903296900511518755E0),
+  pimacosr4375 = L(2.0236129215398221908706530535894517323217E0),
 
   /* asin(x) = x + x^3 pS(x^2) / qS(x^2)
      0 <= x <= 0.5
      peak relative error 1.9e-35  */
-  pS0 = -8.358099012470680544198472400254596543711E2L,
-  pS1 =  3.674973957689619490312782828051860366493E3L,
-  pS2 = -6.730729094812979665807581609853656623219E3L,
-  pS3 =  6.643843795209060298375552684423454077633E3L,
-  pS4 = -3.817341990928606692235481812252049415993E3L,
-  pS5 =  1.284635388402653715636722822195716476156E3L,
-  pS6 = -2.410736125231549204856567737329112037867E2L,
-  pS7 =  2.219191969382402856557594215833622156220E1L,
-  pS8 = -7.249056260830627156600112195061001036533E-1L,
-  pS9 =  1.055923570937755300061509030361395604448E-3L,
+  pS0 = L(-8.358099012470680544198472400254596543711E2),
+  pS1 =  L(3.674973957689619490312782828051860366493E3),
+  pS2 = L(-6.730729094812979665807581609853656623219E3),
+  pS3 =  L(6.643843795209060298375552684423454077633E3),
+  pS4 = L(-3.817341990928606692235481812252049415993E3),
+  pS5 =  L(1.284635388402653715636722822195716476156E3),
+  pS6 = L(-2.410736125231549204856567737329112037867E2),
+  pS7 =  L(2.219191969382402856557594215833622156220E1),
+  pS8 = L(-7.249056260830627156600112195061001036533E-1),
+  pS9 =  L(1.055923570937755300061509030361395604448E-3),
 
-  qS0 = -5.014859407482408326519083440151745519205E3L,
-  qS1 =  2.430653047950480068881028451580393430537E4L,
-  qS2 = -4.997904737193653607449250593976069726962E4L,
-  qS3 =  5.675712336110456923807959930107347511086E4L,
-  qS4 = -3.881523118339661268482937768522572588022E4L,
-  qS5 =  1.634202194895541569749717032234510811216E4L,
-  qS6 = -4.151452662440709301601820849901296953752E3L,
-  qS7 =  5.956050864057192019085175976175695342168E2L,
-  qS8 = -4.175375777334867025769346564600396877176E1L;
+  qS0 = L(-5.014859407482408326519083440151745519205E3),
+  qS1 =  L(2.430653047950480068881028451580393430537E4),
+  qS2 = L(-4.997904737193653607449250593976069726962E4),
+  qS3 =  L(5.675712336110456923807959930107347511086E4),
+  qS4 = L(-3.881523118339661268482937768522572588022E4),
+  qS5 =  L(1.634202194895541569749717032234510811216E4),
+  qS6 = L(-4.151452662440709301601820849901296953752E3),
+  qS7 =  L(5.956050864057192019085175976175695342168E2),
+  qS8 = L(-4.175375777334867025769346564600396877176E1);
   /* 1.000000000000000000000000000000000000000E0 */
 
-long double
-__ieee754_acosl (long double x)
+_Float128
+__ieee754_acosl (_Float128 x)
 {
-  long double z, r, w, p, q, s, t, f2;
+  _Float128 z, r, w, p, q, s, t, f2;
   int32_t ix, sign;
   ieee854_long_double_shape_type u;
 
@@ -204,7 +204,7 @@ __ieee754_acosl (long double x)
 	  return z;
 	}
       /* .4375 <= |x| < .5 */
-      t = u.value - 0.4375L;
+      t = u.value - L(0.4375);
       p = ((((((((((P10 * t
 		    + P9) * t
 		   + P8) * t
@@ -237,7 +237,7 @@ __ieee754_acosl (long double x)
     }
   else if (ix < 0x3ffe4000)	/* |x| < 0.625 */
     {
-      t = u.value - 0.5625L;
+      t = u.value - L(0.5625);
       p = ((((((((((rS10 * t
 		    + rS9) * t
 		   + rS8) * t
