@@ -1,5 +1,5 @@
 /* Quad-precision floating point sine on <-pi/4,pi/4>.
-   Copyright (C) 1999-2016 Free Software Foundation, Inc.
+   Copyright (C) 1999-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Jakub Jelinek <jj@ultra.linux.cz>
 
@@ -21,9 +21,9 @@
 #include <math.h>
 #include <math_private.h>
 
-static const long double c[] = {
+static const _Float128 c[] = {
 #define ONE c[0]
- 1.00000000000000000000000000000000000E+00L, /* 3fff0000000000000000000000000000 */
+ L(1.00000000000000000000000000000000000E+00), /* 3fff0000000000000000000000000000 */
 
 /* cos x ~ ONE + x^2 ( SCOS1 + SCOS2 * x^2 + ... + SCOS4 * x^6 + SCOS5 * x^8 )
    x in <0,1/256>  */
@@ -32,11 +32,11 @@ static const long double c[] = {
 #define SCOS3 c[3]
 #define SCOS4 c[4]
 #define SCOS5 c[5]
--5.00000000000000000000000000000000000E-01L, /* bffe0000000000000000000000000000 */
- 4.16666666666666666666666666556146073E-02L, /* 3ffa5555555555555555555555395023 */
--1.38888888888888888888309442601939728E-03L, /* bff56c16c16c16c16c16a566e42c0375 */
- 2.48015873015862382987049502531095061E-05L, /* 3fefa01a01a019ee02dcf7da2d6d5444 */
--2.75573112601362126593516899592158083E-07L, /* bfe927e4f5dce637cb0b54908754bde0 */
+L(-5.00000000000000000000000000000000000E-01), /* bffe0000000000000000000000000000 */
+ L(4.16666666666666666666666666556146073E-02), /* 3ffa5555555555555555555555395023 */
+L(-1.38888888888888888888309442601939728E-03), /* bff56c16c16c16c16c16a566e42c0375 */
+ L(2.48015873015862382987049502531095061E-05), /* 3fefa01a01a019ee02dcf7da2d6d5444 */
+L(-2.75573112601362126593516899592158083E-07), /* bfe927e4f5dce637cb0b54908754bde0 */
 
 /* sin x ~ ONE * x + x^3 ( SIN1 + SIN2 * x^2 + ... + SIN7 * x^12 + SIN8 * x^14 )
    x in <0,0.1484375>  */
@@ -48,14 +48,14 @@ static const long double c[] = {
 #define SIN6 c[11]
 #define SIN7 c[12]
 #define SIN8 c[13]
--1.66666666666666666666666666666666538e-01L, /* bffc5555555555555555555555555550 */
- 8.33333333333333333333333333307532934e-03L, /* 3ff811111111111111111111110e7340 */
--1.98412698412698412698412534478712057e-04L, /* bff2a01a01a01a01a01a019e7a626296 */
- 2.75573192239858906520896496653095890e-06L, /* 3fec71de3a556c7338fa38527474b8f5 */
--2.50521083854417116999224301266655662e-08L, /* bfe5ae64567f544e16c7de65c2ea551f */
- 1.60590438367608957516841576404938118e-10L, /* 3fde6124613a811480538a9a41957115 */
--7.64716343504264506714019494041582610e-13L, /* bfd6ae7f3d5aef30c7bc660b060ef365 */
- 2.81068754939739570236322404393398135e-15L, /* 3fce9510115aabf87aceb2022a9a9180 */
+L(-1.66666666666666666666666666666666538e-01), /* bffc5555555555555555555555555550 */
+ L(8.33333333333333333333333333307532934e-03), /* 3ff811111111111111111111110e7340 */
+L(-1.98412698412698412698412534478712057e-04), /* bff2a01a01a01a01a01a019e7a626296 */
+ L(2.75573192239858906520896496653095890e-06), /* 3fec71de3a556c7338fa38527474b8f5 */
+L(-2.50521083854417116999224301266655662e-08), /* bfe5ae64567f544e16c7de65c2ea551f */
+ L(1.60590438367608957516841576404938118e-10), /* 3fde6124613a811480538a9a41957115 */
+L(-7.64716343504264506714019494041582610e-13), /* bfd6ae7f3d5aef30c7bc660b060ef365 */
+ L(2.81068754939739570236322404393398135e-15), /* 3fce9510115aabf87aceb2022a9a9180 */
 
 /* sin x ~ ONE * x + x^3 ( SSIN1 + SSIN2 * x^2 + ... + SSIN4 * x^6 + SSIN5 * x^8 )
    x in <0,1/256>  */
@@ -64,23 +64,23 @@ static const long double c[] = {
 #define SSIN3 c[16]
 #define SSIN4 c[17]
 #define SSIN5 c[18]
--1.66666666666666666666666666666666659E-01L, /* bffc5555555555555555555555555555 */
- 8.33333333333333333333333333146298442E-03L, /* 3ff81111111111111111111110fe195d */
--1.98412698412698412697726277416810661E-04L, /* bff2a01a01a01a01a019e7121e080d88 */
- 2.75573192239848624174178393552189149E-06L, /* 3fec71de3a556c640c6aaa51aa02ab41 */
--2.50521016467996193495359189395805639E-08L, /* bfe5ae644ee90c47dc71839de75b2787 */
+L(-1.66666666666666666666666666666666659E-01), /* bffc5555555555555555555555555555 */
+ L(8.33333333333333333333333333146298442E-03), /* 3ff81111111111111111111110fe195d */
+L(-1.98412698412698412697726277416810661E-04), /* bff2a01a01a01a01a019e7121e080d88 */
+ L(2.75573192239848624174178393552189149E-06), /* 3fec71de3a556c640c6aaa51aa02ab41 */
+L(-2.50521016467996193495359189395805639E-08), /* bfe5ae644ee90c47dc71839de75b2787 */
 };
 
 #define SINCOSL_COS_HI 0
 #define SINCOSL_COS_LO 1
 #define SINCOSL_SIN_HI 2
 #define SINCOSL_SIN_LO 3
-extern const long double __sincosl_table[];
+extern const _Float128 __sincosl_table[];
 
-long double
-__kernel_sinl(long double x, long double y, int iy)
+_Float128
+__kernel_sinl(_Float128 x, _Float128 y, int iy)
 {
-  long double h, l, z, sin_l, cos_l_m1;
+  _Float128 h, l, z, sin_l, cos_l_m1;
   int64_t ix;
   u_int32_t tix, hix, index;
   GET_LDOUBLE_MSW64 (ix, x);
