@@ -1,5 +1,4 @@
-/* Copyright (C) 1994,1995,1996,1997,1999,2002,2003,2004,2012
-	Free Software Foundation, Inc.
+/* Copyright (C) 1994-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -42,15 +41,14 @@ __mmap (__ptr_t addr, size_t len, int prot, int flags, int fd, off_t offset)
   mapaddr = (vm_address_t) addr;
 
   /* ADDR and OFFSET must be page-aligned.  */
-  if ((mapaddr & (vm_page_size - 1)) || (offset & (vm_page_size - 1)))
+  if ((mapaddr & (__vm_page_size - 1)) || (offset & (__vm_page_size - 1)))
     return (__ptr_t) (long int) __hurd_fail (EINVAL);
 
   if ((flags & (MAP_TYPE|MAP_INHERIT)) == MAP_ANON
       && prot == (PROT_READ|PROT_WRITE)) /* cf VM_PROT_DEFAULT */
     {
       /* vm_allocate has (a little) less overhead in the kernel too.  */
-      err = __vm_allocate (__mach_task_self (), &mapaddr, len,
-			   mapaddr == NULL);
+      err = __vm_allocate (__mach_task_self (), &mapaddr, len, mapaddr == 0);
 
       if (err == KERN_NO_SPACE)
 	{
@@ -62,7 +60,7 @@ __mmap (__ptr_t addr, size_t len, int prot, int flags, int fd, off_t offset)
 	      if (!err)
 		err = __vm_allocate (__mach_task_self (), &mapaddr, len, 0);
 	    }
-	  else if (mapaddr != NULL)
+	  else if (mapaddr != 0)
 	    err = __vm_allocate (__mach_task_self (), &mapaddr, len, 1);
 	}
 
@@ -98,6 +96,13 @@ __mmap (__ptr_t addr, size_t len, int prot, int flags, int fd, off_t offset)
 	  }
 	switch (prot & (PROT_READ|PROT_WRITE))
 	  {
+	  /* Although it apparently doesn't make sense to map a file with
+	     protection set to PROT_NONE, it is actually sometimes done.
+	     In particular, that's how localedef reserves some space for
+	     the locale archive file, the rationale being that some
+	     implementations take into account whether the mapping is
+	     anonymous or not when selecting addresses.  */
+	  case PROT_NONE:
 	  case PROT_READ:
 	    memobj = robj;
 	    if (wobj != MACH_PORT_NULL)
@@ -127,8 +132,8 @@ __mmap (__ptr_t addr, size_t len, int prot, int flags, int fd, off_t offset)
 		return (__ptr_t) (long int) __hurd_fail (EACCES);
 	      }
 	    break;
-	  default:		/* impossible */
-	    return 0;
+	  default:
+	    __builtin_unreachable ();
 	  }
 	break;
 	/* XXX handle MAP_NOEXTEND */
@@ -139,7 +144,7 @@ __mmap (__ptr_t addr, size_t len, int prot, int flags, int fd, off_t offset)
 
   err = __vm_map (__mach_task_self (),
 		  &mapaddr, (vm_size_t) len, (vm_address_t) 0,
-		  mapaddr == NULL,
+		  mapaddr == 0,
 		  memobj, (vm_offset_t) offset,
 		  ! (flags & MAP_SHARED),
 		  vmprot, VM_PROT_ALL,
@@ -161,7 +166,7 @@ __mmap (__ptr_t addr, size_t len, int prot, int flags, int fd, off_t offset)
 			    (flags & MAP_SHARED) ? VM_INHERIT_SHARE
 			    : VM_INHERIT_COPY);
 	}
-      else if (mapaddr != NULL)
+      else if (mapaddr != 0)
 	err = __vm_map (__mach_task_self (),
 			&mapaddr, (vm_size_t) len, (vm_address_t) 0,
 			1, memobj, (vm_offset_t) offset,
