@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2014 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -23,8 +23,7 @@
 
 /* Remove the link named NAME.  */
 int
-__unlink (name)
-     const char *name;
+__unlink (const char *name)
 {
   error_t err;
   file_t dir;
