@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -222,9 +222,7 @@ static int __rtld_have_atfcts;
    unless SIZE == 0, in which case it is as big as necessary.  */
 
 GETCWD_RETURN_TYPE
-__getcwd (buf, size)
-     char *buf;
-     size_t size;
+__getcwd (char *buf, size_t size)
 {
 #ifndef __ASSUME_ATFCTS
   static const char dots[]
