@@ -1,5 +1,5 @@
 /* Set current rounding direction.
-   Copyright (C) 2000-2014 Free Software Foundation, Inc.
+   Copyright (C) 2000-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Denis Joseph Barrow (djbarrow@de.ibm.com).
 
@@ -21,17 +21,19 @@
 #include <fpu_control.h>
 
 int
-fesetround (int round)
+__fesetround (int round)
 {
   if ((round|FPC_RM_MASK) != FPC_RM_MASK)
     {
       /* ROUND is not a valid rounding mode.  */
       return 1;
     }
-  __asm__ volatile ("srnm 0(%0)"
-		    :
-		    : "a" (round));
+  __asm__ __volatile__ ("srnm 0(%0)"
+			:
+			: "a" (round));
 
   return 0;
 }
-libm_hidden_def (fesetround)
+libm_hidden_def (__fesetround)
+weak_alias (__fesetround, fesetround)
+libm_hidden_weak (fesetround)
