@@ -1,6 +1,6 @@
 /* Set flags signalling availability of kernel features based on given
    kernel version number.
-   Copyright (C) 2006-2015 Free Software Foundation, Inc.
+   Copyright (C) 2006-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -18,28 +18,9 @@
    <http://www.gnu.org/licenses/>.  */
 
 
-/* PA-RISC 2.6.9 kernels had the first LWS CAS support */
-#define __ASSUME_LWS_CAS		1
-
-/* Support for the accept4 and recvmmsg syscalls was added in 2.6.34.  */
-#if __LINUX_KERNEL_VERSION >= 0x020622
-# define __ASSUME_ACCEPT4_SYSCALL	1
-# define __ASSUME_RECVMMSG_SYSCALL	1
-#endif
-
-/* Support for the sendmmsg syscall was added in 3.1.  */
-#if __LINUX_KERNEL_VERSION >= 0x030100
-# define __ASSUME_SENDMMSG_SYSCALL	1
-#endif
-
 /* Support for the utimes syscall was added in 3.14.  */
 #if __LINUX_KERNEL_VERSION >= 0x030e00
 # define __ASSUME_UTIMES		1
 #endif
 
 #include_next <kernel-features.h>
-
-/* The prlimit64 syscall was added for PA in 2.6.37.  */
-#if __LINUX_KERNEL_VERSION < 0x020625
-# undef __ASSUME_PRLIMIT64
-#endif
