@@ -1,4 +1,4 @@
-/* Copyright (C) 2009-2016 Free Software Foundation, Inc.
+/* Copyright (C) 2009-2017 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Jakub Jelinek <jakub@redhat.com>.
 
@@ -34,7 +34,7 @@
     {									\
       uintptr_t cur_sp;							\
       uintptr_t new_sp = env->__gregs[9];				\
-      __asm__ ("lr %0, %%r15" : "=r" (cur_sp));				\
+      __asm__ ("lgr %0, %%r15" : "=r" (cur_sp));			\
       new_sp ^= guard;							\
       if (new_sp < cur_sp)						\
 	{								\
